package com.sf.payment.domain;

import lombok.Data;

import java.util.List;

/**
 * 功能描述:
 * 当前订阅最新的未来扣费计划
 * @author a_kun
 * @date 2024/4/16 15:29
 */
@Data
public class SubRenewalInfo {

    /**
     * 订阅连续购买段的唯一ID，
     * 当用户切换商品不会重置此ID。
     */
    private String subGroupGenerationId;

    /**
     * 下周期生效场景下，下期将续期的商品ID。
     */
    private String nextRenewPeriodProductId;

    /**
     * 当前生效的商品ID。
     */
    private String productId;

    /**
     * 自动续期状态。
     * •	0：关闭
     * •	1：打开
     */
    private Integer autoRenewStatusCode;

    /**
     * 系统是否还在尝试扣费。
     * •	true：是
     * •	false：否
     */
    private Boolean hasInBillingRetryPeriod;

    /**
     * 目前涨价状态码。
     * •	1：用户暂未同意涨价
     * •	2：用户已同意涨价
     */
    private Integer priceIncreaseStatusCode;

    /**
     * 优惠类型。
     * •	1：推介促销
     */
    private Integer offerTypeCode;

    /**
     * 优惠ID。
     */
    private String offerId;

    /**
     * 下期续费价格，单位：分，取消订阅场景下不返回。
     */
    private String renewalPrice;

    /**
     * 币种。
     */
    private String currency;

    /**
     * 续期时间，UTC时间戳，以毫秒为单位。。
     */
    private Long renewalTime;

    /**
     * 订阅续期失败的原因。
     * •	1：用户取消
     * •	2：商品无效
     * •	3：签约无效
     * •	4：扣费异常
     * •	5：用户不同意涨价
     * •	6：未知
     */
    private String expirationIntent;


}
