package com.sf.service.gateway.enums;

import org.springframework.util.StringUtils;

/**
 * 支持的加密算法
 * 目前支持 ECC、RSA 和国密（SM2）
 *
 * @author zoukun
 */
public enum EncryptionAlgorithm
{
    ECC("ECC", "ECC"),
    RSA("RSA", "RSA"),
    SM2("SM2", "国密（SM2）"),
    ;

    private final String code;
    private final String info;

    EncryptionAlgorithm(String code, String info)
    {
        this.code = code;
        this.info = info;
    }

    public String getCode()
    {
        return code;
    }

    public String getInfo()
    {
        return info;
    }

    public static EncryptionAlgorithm getByCode(String code){
        if (StringUtils.hasText(code)){
            for (EncryptionAlgorithm value : EncryptionAlgorithm.values()) {
                if (value.code.equals(code)){
                    return value;
                }
            }
        }
        return null;
    }
    /*
    密钥生成方法
        根据您的业务需求，查看生成密钥的方法。密钥包括 RSA 密钥、ECC 密钥、国密密钥。

        前置条件
        您已通过 OpenSSL 官网 下载并安装 OpenSSL 工具（1.1.1 或以上版本）。

        生成 RSA 密钥
        打开 OpenSSL 工具，使用以下命令行生成 RSA 私钥。您可以选择生成 1024 或 2048 位的私钥。
        openssl genpkey -algorithm RSA -out private_key.pem -pkeyopt rsa_keygen_bits:2048
        根据 RSA 私钥生成 RSA 公钥。
        openssl rsa -pubout -in private_key.pem -out public_key.pem

        生成 ECC 密钥
        打开 OpenSSL 工具，使用以下命令行生成 ECC 的密钥对。您必须选择 secp256k1 椭圆曲线算法。
        openssl ecparam -name secp256k1 -genkey -noout -out secp256k1-key.pem
        根据 secp256k1-key.pem 密钥对生成 ECC 公钥。
        openssl ec -in secp256k1-key.pem -pubout -out ecpubkey.pem

        生成国密密钥
        打开 OpenSSL 工具，使用以下命令行生成国密 SM2 私钥 sm2-key.pem。
        openssl ecparam -name SM2 -genkey -noout -out sm2-key.pem
        根据 sm2-key.pem 密钥对生成国密 SM2 公钥 sm2pubkey.pem。
        openssl ec -in sm2-key.pem -pubout -out sm2pubkey.pem
     */
}
