package com.sf.service.gateway.service;

import com.sf.service.gateway.domain.GatewayInterfaceInfo;
import com.sf.service.gateway.domain.GatewayInterfaceLinkStrategy;
import com.sf.service.gateway.domain.GatewayInterfaceMock;
import com.sf.service.gateway.domain.dto.InsertOrUpdateGatewayInterfaceInfoDTO;
import com.sf.service.gateway.enums.GatewayDataStatus;

import java.util.Collection;
import java.util.List;
import java.util.Set;

/**
 * 接口管理Service接口
 * 
 * @author zoukun
 * @date 2024-04-22
 */
public interface IGatewayInterfaceInfoService 
{
    /**
     * 查询接口管理
     * 
     * @param id 接口管理主键
     * @return 接口管理
     */
    public GatewayInterfaceInfo selectGatewayInterfaceInfoById(Long id);

    /**
     * 查询接口管理列表
     * 
     * @param gatewayInterfaceInfo 接口管理
     * @return 接口管理集合
     */
    public List<GatewayInterfaceInfo> selectGatewayInterfaceInfoList(GatewayInterfaceInfo gatewayInterfaceInfo);

    /**
     * 新增接口管理
     * 
     * @param gatewayInterfaceInfo 接口管理
     * @return 插入后的id
     */
    public Long insertGatewayInterfaceInfo(GatewayInterfaceInfo gatewayInterfaceInfo);

    /**
     * 修改接口管理
     * 
     * @param gatewayInterfaceInfo 接口管理
     * @return 结果
     */
    public int updateGatewayInterfaceInfo(GatewayInterfaceInfo gatewayInterfaceInfo);

    /**
     * 批量删除接口管理
     * 
     * @param ids 需要删除的接口管理主键集合
     * @return 结果
     */
    public int deleteGatewayInterfaceInfoByIds(Long[] ids);

    /**
     * 删除接口管理信息
     * 
     * @param id 接口管理主键
     * @return 结果
     */
    public int deleteGatewayInterfaceInfoById(Long id);

    int updateGatewayInterfaceInfoStatusByIds(Collection<Long> ids, GatewayDataStatus status);

    List<GatewayInterfaceInfo> selectGatewayInterfaceInfoByServerIds(Collection<Long> serverIds);

    List<GatewayInterfaceInfo> selectGatewayInterfaceInfoByIds(Collection<Long> ids);

    /**
     * 添加接口信息及绑定的策略信息
     *
     * @param dto
     * @return
     */
    Long insertGatewayInterfaceInfoAndBindStrategy(InsertOrUpdateGatewayInterfaceInfoDTO dto);

    /**
     * 修改接口信息及绑定的策略信息
     * @param dto
     * @return
     */
    Long updateGatewayInterfaceInfoAndBindStrategy(InsertOrUpdateGatewayInterfaceInfoDTO dto);

    List<GatewayInterfaceLinkStrategy> selectGatewayInterfaceLinkStrategyByInterfaceIds(Collection<Long> interfaceIds);

    List<GatewayInterfaceMock> selectGatewayInterfaceMockListByInterfaceIds(Collection<Long> interfaceIds);
}
