package com.sf.vertx.handle;

import io.vertx.core.buffer.Buffer;
import org.apache.commons.lang3.StringUtils;

import com.sf.vertx.constans.SacErrorCode;

import io.vertx.core.http.HttpHeaders;
import io.vertx.core.json.JsonObject;
import io.vertx.ext.web.RoutingContext;
import io.vertx.ext.web.handler.HttpException;
import lombok.extern.slf4j.Slf4j;

@Slf4j
public class RestfulFailureHandlerImpl implements RestfulFailureHandler {

	@Override
	public void handle(RoutingContext frc) {
		int statusCode = 500;
		JsonObject errorJson = null;
		Integer sc = SacErrorCode.DEFAULT_ERROR_CODE;
		try {
			Throwable failure = frc.failure();
			log.info("failure:", failure);
			if (failure instanceof HttpException) {
				HttpException httpException = (HttpException) failure;
				sc = httpException.getStatusCode();
				if (StringUtils.isNoneBlank(httpException.getPayload())) {
					errorJson = new JsonObject(httpException.getPayload());
				} else {
					errorJson = SacErrorCode.returnErrorMsg(httpException.getStatusCode());
				}
			} else if (failure instanceof MockException) {
				MockException httpException = (MockException) failure;
				sc = httpException.getStatusCode();
				statusCode = httpException.getStatusCode();
				if (StringUtils.isNoneBlank(httpException.getPayload())) {
					errorJson = new JsonObject(httpException.getPayload());
				} else {
					errorJson = SacErrorCode.returnErrorMsg(httpException.getStatusCode());
				}
			} else {
				errorJson = SacErrorCode.returnErrorMsg(SacErrorCode.DEFAULT_ERROR_CODE);
			}

		} catch (Exception e) {
			e.printStackTrace();
			errorJson = SacErrorCode.returnErrorMsg(SacErrorCode.DEFAULT_ERROR_CODE);
		}

		frc.response().setChunked(true).setStatusCode(statusCode).putHeader("Content-Type", "application/json")
				.putHeader(AppConfigHandler.sacResponseHeaderKey(), String.valueOf(sc))
				.end(errorJson.toBuffer());
		return;
	}

}
